# Examples

## Instructions

1. Log in to your databricks workspace
2. Run any cluster or serverless compute
3. Clone the repo into the workspace or import specific notebooks

## Examples

All examples can be found here: https://github.com/stikkireddy/mlflow-extensions/tree/main/examples/notebooks